--
-- kopaczka jednorzedowa do ziemniakow
-- @author: Burner
--

kopaczka = {};

function kopaczka.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Trailer, specializations);
end;

function kopaczka:load(xmlFile)
    self.wasToFast = false;
	self.isLowered = false;
	self.ziemniaki = {};
    local i = 0;

    while true do
        local namei = string.format("vehicle.ziemniaki.ziemniaki(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.ziemniaki, namei, nodei, false, nil, self.baseDirectory)		
		Utils.setEmittingState(self.ziemniaki,false)
		self.particleSystemdisableTime = 0;
		i = i +1;		
    end;

	self.dropAreas = {}
	local numDropAreas = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.dropAreas#count"), 0);
    for i=1, numDropAreas do
		self.dropAreas[i] = {};
        local areanamei = string.format("vehicle.dropAreas.dropArea%d", i);
        self.dropAreas[i].start = Utils.indexToObject(self.components, getXMLString(xmlFile, areanamei .. "#startIndex"));
        self.dropAreas[i].width = Utils.indexToObject(self.components, getXMLString(xmlFile, areanamei .. "#widthIndex"));
        self.dropAreas[i].height = Utils.indexToObject(self.components, getXMLString(xmlFile, areanamei .. "#heightIndex"));
    end;
	
	local kopaczkaBaseNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.kopaczkaBase#index"));
    if kopaczkaBaseNode ~= nil then
        self.kopaczkaBase = {};
        self.kopaczkaBase.node = kopaczkaBaseNode;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.kopaczkaBase#minRot"));
        self.kopaczkaBase.minRot = {};
        self.kopaczkaBase.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.kopaczkaBase.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.kopaczkaBase.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.kopaczkaBase#maxRot"));
        self.kopaczkaBase.maxRot = {};
        self.kopaczkaBase.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.kopaczkaBase.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.kopaczkaBase.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.kopaczkaBase.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.kopaczkaBase#rotTime"), 2)*1000;
        self.kopaczkaBase.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.kopaczkaBase#touchRotLimit"), 10));
    end;
	
	local wajchaNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.wajcha#index"));
    if wajchaNode ~= nil then
        self.wajcha = {};
        self.wajcha.node = wajchaNode;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.wajcha#minRot"));
        self.wajcha.minRot = {};
        self.wajcha.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.wajcha.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.wajcha.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.wajcha#maxRot"));
        self.wajcha.maxRot = {};
        self.wajcha.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.wajcha.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.wajcha.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.wajcha.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.wajcha#rotTime"), 2)*1000;
        self.wajcha.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.wajcha#touchRotLimit"), 10));
    end;
	
	local smiglo = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.smiglo#index"));
	if smiglo ~= nil then
		self.smiglo = smiglo;
	end;
end;

function kopaczka:update(dt)
	if self:getIsActiveForInput() then
        if InputBinding.hasEvent(InputBinding.LOWER_IMPLEMENT) then
           self.isLowered = not self.isLowered;
		end;
    end;
	self.wasToFast = false;
	if self:getIsActive() then
		if self.kopaczkaBase ~= nil then
			local x, y, z = getRotation(self.kopaczkaBase.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.kopaczkaBase.maxRot, self.kopaczkaBase.minRot, 3, self.kopaczkaBase.rotTime, dt, self.isLowered);
			setRotation(self.kopaczkaBase.node,unpack(newRot));	
		end;
		if self.wajcha ~= nil then
			local x, y, z = getRotation(self.wajcha.node);
			local rot = {x,y,z};
			local newRot = Utils.getMovedLimitedValues(rot, self.wajcha.maxRot, self.wajcha.minRot, 3, self.wajcha.rotTime, dt, self.isLowered);
			setRotation(self.wajcha.node,unpack(newRot));	
		end;
		if self.isLowered then
			local toFast = self:doCheckSpeedLimit() and self.attacherVehicle.lastSpeed*3600 > 20;
			if not toFast then				
				local area =0;
				for k, cuttingArea in pairs(self.cuttingAreas) do
					local x,y,z = getWorldTranslation(cuttingArea.start);
					local x1,y1,z1 = getWorldTranslation(cuttingArea.width);
					local x2,y2,z2 = getWorldTranslation(cuttingArea.height);
					Utils.updateFruitCutShortArea(FruitUtil.FRUITTYPE_POTATO, x, z, x1, z1, x2, z2, 1);									
					local area = Utils.cutFruitArea(FruitUtil.FRUITTYPE_POTATO, x, z, x1, z1, x2, z2, 1);
					if area > 0 then
						for s, dropArea in pairs(self.dropAreas) do
							local x,y,z = getWorldTranslation(dropArea.start);
							local x1,y1,z1 = getWorldTranslation(dropArea.width);
							local x2,y2,z2 = getWorldTranslation(dropArea.height);
							Utils.updateFruitCutLongArea(FruitUtil.FRUITTYPE_POTATO, x, z, x1, z1, x2, z2, 1, true);
						end;
						self.particleSystemdisableTime = self.time + 200;
						Utils.setEmittingState(self.ziemniaki, true)
					end;
				end;							
			end;
			wrx,wry,wrz = getRotation(self.wheels[1].repr);
			setRotation(self.smiglo,0,0,-wrx);
			self.wasToFast = toFast;
		end;
	end;
	if self.time > self.particleSystemdisableTime then
		Utils.setEmittingState(self.ziemniaki, false);
	end;
end;

function kopaczka:mouseEvent(posX, posY, isDown, isUp, button)
end;

function kopaczka:keyEvent(unicode, sym, modifier, isDown)
end;

function kopaczka:draw()
	if self.attacherVehicle.lastSpeed*3600 > 21 and self.isLowered then
		g_currentMission:addWarning(g_i18n:getText("Dont_drive_to_fast") .. "\n" .. string.format(g_i18n:getText("Cruise_control_levelN"), "1", InputBinding.getKeyNamesOfDigitalAction(InputBinding.SPEED_LEVEL1)), 0.07+0.022, 0.019+0.029);
	end;
	if self.isLowered then
		g_currentMission:addHelpButtonText("Podnies kopaczke", InputBinding.LOWER_IMPLEMENT);	
    else
		g_currentMission:addHelpButtonText("Opusc kopaczke", InputBinding.LOWER_IMPLEMENT);	
    end;
end;

function kopaczka:onAttach()
end; 	

function kopaczka:onDetach()
	self.isLowered = false;
end;

function kopaczka:onDeactivate()
end;

function kopaczka:delete()
end;

function kopaczka:onLeave()
end;